# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing import List
from typing_extensions import NotRequired, TypedDict


class MeterUpdateParams(TypedDict):
    display_name: NotRequired[str]
    """
    The meter's name. Not visible to the customer.
    """
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
